@@ -21,6 +21,7 @@ use deno_crypto::rand::Rng;
 use log::debug;
 use serde::Deserialize;
 use serde::Serialize;
+use std::borrow::Cow;
 use std::cell::RefCell;
 use std::convert::From;
 use std::env::{current_dir, set_current_dir, temp_dir};
@@ -1905,7 +1906,7 @@ fn op_readfile_text_sync(state: &mut OpState, path: String) -> Result<String, An
     let permissions = state.borrow_mut::<Permissions>();
     let path = Path::new(&path);
     permissions.read.check(path)?;
-    Ok(std::fs::read_to_string(path)?)
+    Ok(string_from_utf8_lossy(std::fs::read(path)?))
 }
 
 #[op]
@@ -1948,7 +1949,7 @@ async fn op_readfile_text_async(
     }
     let fut = tokio::task::spawn_blocking(move || {
         let path = Path::new(&path);
-        Ok(String::from_utf8(std::fs::read(path)?)?)
+        Ok(string_from_utf8_lossy(std::fs::read(path)?))
     });
     if let Some(cancel_rid) = cancel_rid {
         let cancel_handle = state
@@ -1961,3 +1962,14 @@ async fn op_readfile_text_async(
     }
     fut.await?
 }
+
+// Like String::from_utf8_lossy but operates on owned values
+fn string_from_utf8_lossy(buf: Vec<u8>) -> String {
+    match String::from_utf8_lossy(&buf) {
+        // buf contained non-utf8 chars than have been patched
+        Cow::Owned(s) => s,
+        // SAFETY: if Borrowed then the buf only contains utf8 chars,
+        // we do this instead of .into_owned() to avoid copying the input buf
+        Cow::Borrowed(_) => unsafe { String::from_utf8_unchecked(buf) },
+    }
+}
